"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_1 = require("winston");
const app_root_path_1 = __importDefault(require("app-root-path"));
const { combine, timestamp, label, printf } = winston_1.format;
class ServiceLogger {
    constructor(serviceName, instanceName, path, face) {
        this.logger = null;
        this.mode = "normal";
        this.serviceName = serviceName;
        this.instanceName = instanceName;
        this.face = face || null;
        this.path = path || 'logs';
        const style = printf((info) => {
            return `${this.serviceName} | [${new Date().toISOString()}] ${this.instanceName}    ${info.message}`;
        });
        const options = {
            file: {
                filename: `${app_root_path_1.default}/${this.path}/${this.serviceName}.log`,
                handleExceptions: true,
                json: true,
                maxsize: 5242880,
                maxFiles: 1,
                colorize: false
            },
            console: {
                handleExceptions: true,
                json: false,
                colorize: true
            }
        };
        this.logger = winston_1.createLogger({
            format: combine(timestamp(), style),
            transports: [
                new winston_1.transports.File(options.file),
                new winston_1.transports.Console(options.console)
            ],
            exitOnError: false
        });
    }
    info(message) {
        if (this.logger != null)
            this.logger.info(message);
    }
    warn(message) {
        if (this.logger != null)
            this.logger.warn(message);
    }
    err(message) {
        if (this.logger != null)
            this.logger.error(message);
    }
    silent() {
        this.mode = 'silent';
    }
}
class LogManager {
    constructor(serviceName, path) {
        this.serviceName = serviceName;
        this.path = path || 'logs';
    }
    getLogger(instanceName) {
        return new ServiceLogger(this.serviceName, instanceName, this.path);
    }
}
exports.default = LogManager;
//# sourceMappingURL=index.js.map